#
# spec file for package gpu-screen-recorder
#
# Copyright (c) 2024 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with test
Name:           gpu-screen-recorder
Version:        20240921
Release:        1.1
Summary:        An extremely fast hardware-accelerated screen recorder
License:        GPL-3.0-only
URL:            https://git.dec05eba.com/gpu-screen-recorder/about
Source:         %{name}-%{version}.tar.zst
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  zstd
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrandr)

%description
This is a screen recorder that has minimal impact on system performance
by recording your monitor using the GPU only, similar to ShadowPlay on
windows. This is the fastest screen recording tool for Linux.

This screen recorder can be used for recording your desktop offline, for
live streaming and for nvidia ShadowPlay-like instant replay, where only
the last few minutes are saved.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%if 0%{?suse_version} < 1600
rm %{buildroot}/usr/lib/modprobe.d/gsr-nvidia.conf
%endif

%if %{with test}
%check
%meson_test
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_bindir}/gsr-kms-server
%{_userunitdir}/%{name}.service
%if 0%{?suse_version} > 1600
%{_modprobedir}/gsr-nvidia.conf
%endif

%changelog
* Mon Sep 23 2024 mantarimay@pm.me
- Update to version 20240921:
  * Fix recording not working on some amd systems
  * Improve screen recording performance on AMD when the system
    usage is very high
  * Fix recording not working on old nvidia gpus (that are stuck
    on nvidia driver version 470)
* Tue Sep 17 2024 mantarimay@pm.me
- Update to version 20240917:
  * Improve video capture sync, making the video smoother. The
    video is smoother on X11 than Wayland.
  * Improve video recording performance on AMD when the system
    usage is 100%%
- Remove pkgconfig(xi) BuildRequires: unneeded anymore on v4.1.8
* Tue Sep 10 2024 mantarimay@pm.me
- Update to version 20240906:
  * Portal: fix external texture
  * Allow prime run with desktop portal
  * Explicit glFlush/glFinish before and after render operations to
    fix tearing and stutter on amd
  * Fix systemd service file
* Sat Aug 31 2024 mantarimay@pm.me
- Update to version 20240831:
  * Disable vaapi info debug log
  * Faster startup (faster video codec query), fix some video codec
    callback logic
  * Add --version command
  * Improve quality again
* Tue Aug 20 2024 mantarimay@pm.me
- Update to version 20240820:
  * Also revert av1 quality
  * Revert quality parameters, they were overkill
  * Explain why portal needs access to process root file
  * x11 cursor deinit: check if display is valid
  * Small refactor in pipewire code, remove unused
    extra/install_preserve_video_memory.sh script
  * Don't install files using absolute paths
* Thu May 16 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
